@@ -21,7 +21,7 @@ MA 02110-1301 USA
 /*
   nepim - network pipemeter
 
-  $Id: main.c,v 1.74 2008/07/11 15:26:33 evertonm Exp $
+  $Id: main.c,v 1.75 2008/08/22 02:01:19 evertonm Exp $
  */
 
 #include <stdlib.h>
@@ -108,6 +108,7 @@ static void usage(FILE *out, const char *prog_name)
 	  "  -Q             quietly hide debug errors\n"
 	  "  -y tos         ip tos (defaults to %d, tos=-1 means don't change)\n"
 	  "  -L             supress output of UDP accumulative loss\n"
+	  "  -E             set IP Router Alert option\n"
 	  "\n"
           "client-only options:\n"
           "  -c host-list   client mode (defaults to server mode)\n"
@@ -265,6 +266,11 @@ int main(int argc, const char *argv[])
   for (i = 1; i < argc; ++i) {
     const char *arg = argv[i];
 
+    if (!strcmp(arg, "-E")) {
+      nepim_global.router_alert = 1; /* boolean */
+      continue;
+    }
+
     if (!strcmp(arg, "-sweep")) {
       int j = i + 1;
 
