@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: server.c,v 1.86 2008/07/11 15:26:33 evertonm Exp $ */
+/* $Id: server.c,v 1.87 2008/08/22 02:01:19 evertonm Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -939,7 +939,8 @@ static void *on_tcp_connect(oop_source *src, int sd,
 
   result = nepim_socket_opt(nepim_global.verbose_stderr,
 			    conn_sd, nepim_global.pmtu_mode, 
-                            nepim_global.ttl, nepim_global.tos);
+                            nepim_global.ttl, nepim_global.tos,
+			    nepim_global.router_alert);
   if (result) {
     fprintf(stderr, 
             "%d: %s: %s: could not set socket options: %d\n",
@@ -1032,6 +1033,7 @@ static int spawn_tcp_listener(const char *hostname, const char *portname)
 				      nodelay,
 				      nepim_global.tos,
 				      nepim_global.server_tcp_mss,
+				      nepim_global.router_alert,
 				      0,  /* join_iface */
 				      0,  /* ssm_src_addr */
 				      -1  /* ssm_src_addrlen */);
@@ -1095,6 +1097,7 @@ static int spawn_unix_listener(const char *path)
 				    nodelay,
 				    nepim_global.tos,
 				    nepim_global.server_tcp_mss,
+				    nepim_global.router_alert,
 				    0, /* iface_index */
 				    0,  /* ssm_src_addr */
 				    -1  /* ssm_src_addrlen */);
