@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: sock.c,v 1.53 2008/07/11 21:40:01 evertonm Exp $ */
+/* $Id: sock.c,v 1.55 2008/08/22 02:01:19 evertonm Exp $ */
 
 #include <assert.h>
 #include <netdb.h>
@@ -116,6 +116,7 @@ struct group_source_req {
 #define NEPIM_SOCK_ERR_SOCK_KA                (-19)
 #define NEPIM_SOCK_ERR_MSS                    (-20)
 #define NEPIM_SOCK_ERR_MCAST_JOIN_IFACE       (-21)
+#define NEPIM_SOCK_ERR_RA                     (-22)
 
 int nepim_sock_get_port(const struct sockaddr *addr)
 {
@@ -342,6 +343,31 @@ int nepim_socket_tos(FILE *err, int sd, int tos)
   return NEPIM_SOCK_ERR_NONE;
 }
 
+/* Set IP router alert option (RFC 2113) */
+static int socket_set_ra(FILE *err, int sd)
+{
+  char ra[4];
+
+  ra[0] = 148;
+  ra[1] = 4;
+  ra[2] = 0;
+  ra[3] = 0;
+
+  if (setsockopt(sd, IPPROTO_IP, IP_OPTIONS, ra, 4)) {
+
+    if (err) {
+      int e = errno;
+      fprintf(err, "%s: %s: setsockopt(RA): sd=%d: errno=%d: %s\n",
+	      __FILE__, __PRETTY_FUNCTION__,
+	      sd, e, strerror(e));
+    }
+
+    return NEPIM_SOCK_ERR_RA;
+  }
+
+  return NEPIM_SOCK_ERR_NONE;
+}
+
 static const char *family_name(int family)
 {
   switch (family) {
@@ -379,7 +405,8 @@ static const char *proto_name(int proto)
 
 static int create_socket(FILE *err, int domain, int type, int protocol,
 			 int pmtu_mode, int ttl, int win_recv,
-			 int win_send, int nodelay, int tos, int mss)
+			 int win_send, int nodelay, int tos, int mss,
+			 int ra)
 {
   int sd;
   int result;
@@ -406,7 +433,7 @@ static int create_socket(FILE *err, int domain, int type, int protocol,
     }
   }
 
-  result = nepim_socket_opt(err, sd, pmtu_mode, ttl, tos);
+  result = nepim_socket_opt(err, sd, pmtu_mode, ttl, tos, ra);
   if (result) {
     close(sd);
     return result;
@@ -785,14 +812,16 @@ int nepim_create_socket(FILE *err,
 			int nodelay,
 			int tos,
 			int mss,
+			int ra,
 			const char *iface,
-			const struct sockaddr *ssm_src_addr, int ssm_src_addrlen)
+			const struct sockaddr *ssm_src_addr,
+			int ssm_src_addrlen)
 {
   int sd;
   int result;
 
   sd = create_socket(err, family, type, protocol, pmtu_mode, ttl,
-		     win_recv, win_send, nodelay, tos, mss);
+		     win_recv, win_send, nodelay, tos, mss, ra);
   if (sd < 0)
     return sd;
 
@@ -912,6 +941,7 @@ int nepim_create_listener_socket(FILE *err,
 				 int nodelay,
 				 int tos,
 				 int mss,
+				 int ra,
 				 const char *iface,
 				 const struct sockaddr *ssm_src_addr, int ssm_src_addrlen)
 {
@@ -920,7 +950,7 @@ int nepim_create_listener_socket(FILE *err,
   sd = nepim_create_socket(err, addr, addr_len, family,
 			   type, protocol, pmtu_mode, 
 			   ttl, 0, win_recv, win_send,
-			   nodelay, tos, mss,
+			   nodelay, tos, mss, ra,
 			   iface, ssm_src_addr, ssm_src_addrlen);
   if (sd < 0)
     return sd;
@@ -1001,7 +1031,7 @@ static int nepim_socket_get_nodelay(FILE *err, int sd)
   return nodelay;
 }
 
-int nepim_socket_opt(FILE *err, int sd, int pmtu_mode, int ttl, int tos)
+int nepim_socket_opt(FILE *err, int sd, int pmtu_mode, int ttl, int tos, int ra)
 {
   if (unlinger(sd))
     return NEPIM_SOCK_ERR_UNLINGER;
@@ -1018,6 +1048,10 @@ int nepim_socket_opt(FILE *err, int sd, int pmtu_mode, int ttl, int tos)
   if (nepim_socket_tos(err, sd, tos))
     return NEPIM_SOCK_ERR_TOS;
 
+  if (ra)
+    if (socket_set_ra(err, sd))
+      return NEPIM_SOCK_ERR_RA;
+
   return NEPIM_SOCK_ERR_NONE;
 }
 
@@ -1124,6 +1158,7 @@ int nepim_connect_client_socket(FILE *err,
 				int tos,
 				int socket_keepalive,
 				int mss,
+				int ra,
 				const char *iface)
 {
   int sd;
@@ -1132,7 +1167,7 @@ int nepim_connect_client_socket(FILE *err,
   sd = nepim_create_socket(err, bind, bind_len,
 			   family, type, protocol, pmtu_mode, ttl,
 			   0 /* mcast_join: false */,
-			   win_recv, win_send, nodelay, tos, mss,
+			   win_recv, win_send, nodelay, tos, mss, ra,
 			   iface,
 			   0,  /* ssm_src_addr */
 			   -1  /* ssm_src_addrlen */);
