@@ -29,7 +29,7 @@ int nepim_socket_block(int sd);
 int nepim_socket_ttl(int sd, int ttl);
 int nepim_socket_mcast_ttl(int sd, int mcast_ttl);
 int nepim_socket_pmtu(int sd, int pmtu_mode);
-int nepim_socket_opt(FILE *err, int sd, int pmtu_mode, int ttl, int tos);
+int nepim_socket_opt(FILE *err, int sd, int pmtu_mode, int ttl, int tos, int ra);
 int nepim_socket_tcp_opt(FILE *err, int family, int sd, int nodelay, int mss);
 int nepim_socket_keepalive(FILE *err, int sd, int keepalive);
 
@@ -51,6 +51,7 @@ int nepim_create_socket(FILE *err,
 			int nodelay,
 			int tos,
 			int mss,
+			int ra,
 			const char *iface,
 			const struct sockaddr *ssm_src_addr, int ssm_src_addrlen);
 int nepim_create_listener_socket(FILE *err,
@@ -67,6 +68,7 @@ int nepim_create_listener_socket(FILE *err,
 				 int nodelay,
 				 int tos,
 				 int mss,
+				 int ra,
 				 const char *iface,
 				 const struct sockaddr *ssm_src_addr, int ssm_src_addrlen);
 int nepim_connect_client_socket(FILE *err,
@@ -83,6 +85,7 @@ int nepim_connect_client_socket(FILE *err,
 				int tos,
 				int socket_keepalive,
 				int mss,
+				int ra,
 				const char *iface);
 int nepim_sock_get_port(const struct sockaddr *addr);
 void nepim_sock_set_port(const struct sockaddr *addr, int port);
